import React, { useState, useEffect } from 'react';
import { StyleSheet, Dimensions, TouchableOpacity } from 'react-native';
import NetInfo from '@react-native-community/netinfo';
import { ThemedText } from '@/src/components/themed/ThemedText';
import { ThemedView } from '@/src/components/themed/ThemedView';
import { Colors } from '@/src/constants/Colors';
import Ionicons from '@expo/vector-icons/Ionicons';
import { useColorScheme } from '@/src/hooks/useColorScheme';
import { useTranslation } from 'react-i18next';

const { width, height } = Dimensions.get( 'window' );

interface NoInternetConnectionScreenProps {
    connected?: () => void;
}

const NoInternetConnectionScreen: React.FC<NoInternetConnectionScreenProps> = ({ connected }) => {
    const colorScheme = useColorScheme() ?? 'light';
    const [ isConnected, setIsConnected ] = useState<boolean | null>( null );
    const { t } = useTranslation();

    useEffect(() => {
        // Listener for when connection is back
        const unsubscribe = NetInfo.addEventListener(state => {
            setIsConnected(state.isConnected);
        });

        // Check initial connection state
        NetInfo.fetch().then(state => {
            setIsConnected(state.isConnected);
        });

        return () => unsubscribe();
    }, []);

    useEffect(() => {
        // Execute callback when connection is made
        if (isConnected && connected) {
            connected();
        }
    }, [isConnected, isConnected]);

    const retryConnection = () => {
        NetInfo.fetch().then(state => {
            setIsConnected(state.isConnected);
        });
    };

    if (isConnected !== false) {
        return null;
    }

    return (
        <ThemedView style={styles.container}>
            <ThemedText style={styles.title}>{t( "internet.no-connection" )}</ThemedText>
            <ThemedText style={styles.message}>
                {t( "internet.please-check" )}
            </ThemedText>

            <TouchableOpacity style={{ ...styles.button, backgroundColor: Colors[ colorScheme ].tint }} onPress={retryConnection}>
                <ThemedText style={{ color: Colors.white }}>
                    {t( "internet.retry" )}
                </ThemedText>
                <Ionicons name={"reload"} size={18} style={styles.buttonIcon}/>
            </TouchableOpacity>
        </ThemedView>
    );
};

const styles = StyleSheet.create( {
    container: {
        position: 'absolute',
        top: 0,
        left: 0,
        width: width,
        height: height + 70, // Tab bar height
        alignItems: 'center',
        justifyContent: 'center',
        padding: 20,
        zIndex: 9999, // Ensure it's on top
    },
    image: {
        width: 120,
        height: 120,
        marginBottom: 20,
    },
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        marginBottom: 10,
    },
    message: {
        fontSize: 16,
        textAlign: 'center',
        marginBottom: 20,
        color: '#666',
    },
    button: {
        borderRadius: 5,
        paddingTop: 10,
        paddingBottom: 10,
        paddingLeft: 40,
        paddingRight: 40,
        marginTop: 30,
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
    },
    buttonIcon: {
        marginLeft: 15,
        paddingTop: 2,
        color: Colors.white
    },
} );

export default NoInternetConnectionScreen;